@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Classification/include/CGAL/Classification/TensorFlow/Neural_network_classifier.h $
-// $Id: Neural_network_classifier.h fb63d96 %aI Simon Giraudot
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0.1/Classification/include/CGAL/Classification/TensorFlow/Neural_network_classifier.h $
+// $Id: Neural_network_classifier.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Simon Giraudot
 
@@ -34,7 +25,6 @@
 
 #include <boost/property_tree/ptree.hpp>
 #include <boost/property_tree/xml_parser.hpp>
-#include <boost/foreach.hpp>
 #include <boost/algorithm/string/predicate.hpp>
 #include <boost/algorithm/string.hpp>
 #include <boost/lexical_cast.hpp>
@@ -129,7 +119,7 @@ public:
   Neural_network_classifier (const Label_set& labels,
                              const Feature_set& features)
     : m_verbose (true), m_labels (labels), m_features (features)
-    , m_root (NULL), m_ph_ft (NULL), m_ph_gt (NULL), m_loss(NULL), m_session (NULL)
+    , m_root (nullptr), m_ph_ft (nullptr), m_ph_gt (nullptr), m_loss(nullptr), m_session (nullptr)
   { }
   
   /// \cond SKIP_IN_MANUAL
@@ -138,7 +128,7 @@ public:
     clear();
   }
 
-  bool initialized() const { return (m_root != NULL); }
+  bool initialized() const { return (m_root != nullptr); }
 
   bool& verbose() { return m_verbose; }
 
@@ -158,9 +148,9 @@ public:
   template <typename T>
   void clear (T* t)
   {
-    if (t != NULL)
+    if (t != nullptr)
       delete t;
-    t = NULL;
+    t = nullptr;
   }
 
   void compute_normalization_coefficients (const std::vector<std::size_t>& indices)
@@ -581,7 +571,7 @@ public:
     m_learning_rate = tree.get<float>("classification.metadata.learning_rate");
 
     std::size_t idx = 0;
-    BOOST_FOREACH(boost::property_tree::ptree::value_type &v, tree.get_child("classification.features"))
+    for(boost::property_tree::ptree::value_type& v : tree.get_child("classification.features"))
     {
       std::string name = v.second.get<std::string>("name");
 
@@ -606,7 +596,7 @@ public:
     }
 
     idx = 0;
-    BOOST_FOREACH(boost::property_tree::ptree::value_type &v, tree.get_child("classification.labels"))
+    for(boost::property_tree::ptree::value_type& v : tree.get_child("classification.labels"))
     {
       std::string name = v.second.get<std::string>("name");
       if (name != m_labels[idx]->name())
@@ -630,7 +620,7 @@ public:
     m_bias.resize (nb_layers);
 
     std::vector<std::size_t> hidden_layers;
-    BOOST_FOREACH(boost::property_tree::ptree::value_type &v, tree.get_child("classification.layers"))
+    for(boost::property_tree::ptree::value_type& v : tree.get_child("classification.layers"))
     {
       if (idx >= nb_layers)
       {
@@ -673,6 +663,8 @@ public:
     return out;
   }
 
+/// @}
+
 private:
 
   template<class BidiIter >
