@@ -2,19 +2,10 @@
 // All rights reserved.
 //
 // This file is part of CGAL (www.cgal.org).
-// You can redistribute it and/or modify it under the terms of the GNU
-// General Public License as published by the Free Software Foundation,
-// either version 3 of the License, or (at your option) any later version.
 //
-// Licensees holding a valid commercial license may use this file in
-// accordance with the commercial license agreement provided with the software.
-//
-// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-//
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Surface_sweep_2/include/CGAL/No_intersection_surface_sweep_2.h $
-// $Id: No_intersection_surface_sweep_2.h 33d3aba %aI Laurent Rineau
-// SPDX-License-Identifier: GPL-3.0+
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0.1/Surface_sweep_2/include/CGAL/No_intersection_surface_sweep_2.h $
+// $Id: No_intersection_surface_sweep_2.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Baruch Zukerman <baruchzu@post.tau.ac.il>
 //             Efi Fogel <efifogel@gmail.com>
@@ -167,17 +158,9 @@ public:
                                                         Status_line;
   typedef typename Status_line::iterator                Status_line_iterator;
 
-#ifdef CGAL_CXX11
   typedef std::allocator_traits<Allocator> Allocator_traits;
   typedef typename Allocator_traits::template rebind_alloc<Event> Event_alloc;
   typedef typename Allocator_traits::template rebind_alloc<Subcurve> Subcurve_alloc;
-#else // not CGAL_CXX11
-  typedef typename Allocator::template rebind<Event>    Event_alloc_rebind;
-  typedef typename Event_alloc_rebind::other            Event_alloc;
-
-  typedef typename Allocator::template rebind<Subcurve> Subcurve_alloc_rebind;
-  typedef typename Subcurve_alloc_rebind::other         Subcurve_alloc;
-#endif // not CGAL_CXX11
   
 protected:
   /*! \struct
@@ -452,7 +435,7 @@ protected:
   /*! Add a subcurve to the right of an event point.
    * \param event The event point.
    * \param curve The subcurve to add.
-   * \return (true) if an overlap occured; (false) otherwise.
+   * \return (true) if an overlap occurred; (false) otherwise.
    */
   virtual bool _add_curve_to_right(Event* event, Subcurve* curve);
 
@@ -500,7 +483,7 @@ protected:
   std::pair<Event*, bool> _push_event(const Point_2& pt, Attribute type,
                                       Arr_parameter_space ps_x,
                                       Arr_parameter_space ps_y,
-                                      Subcurve* sc = NULL);
+                                      Subcurve* sc = nullptr);
 
   /*! Push an event point associated with a curve end into the event queue.
    * \param cv The x-monotone curve.
@@ -518,7 +501,7 @@ protected:
                                       Attribute type,
                                       Arr_parameter_space ps_x,
                                       Arr_parameter_space ps_y,
-                                      Subcurve* sc = NULL);
+                                      Subcurve* sc = nullptr);
 
   void _update_event_at_open_boundary(Event* e,
                                       const X_monotone_curve_2& cv,
