@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0/STL_Extension/include/CGAL/assertions_impl.h $
-// $Id: assertions_impl.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-5.0.1/STL_Extension/include/CGAL/assertions_impl.h $
+// $Id: assertions_impl.h 01f69b5 2019-12-08T01:25:41-08:00 Fritz Mueller
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -30,8 +30,6 @@
 
 namespace CGAL {
 
-namespace {
-
 #ifdef CGAL_HEADER_ONLY
 
 inline Failure_behaviour& get_static_error_behaviour()
@@ -47,6 +45,8 @@ inline Failure_behaviour& get_static_warning_behaviour()
 
 #else // CGAL_HEADER_ONLY
 
+namespace {
+
 // behaviour variables
 // -------------------
 
@@ -58,8 +58,12 @@ inline Failure_behaviour& get_static_error_behaviour()
 inline Failure_behaviour& get_static_warning_behaviour()
 { return _warning_behaviour; }
 
+} // anonymous namespace
+
 #endif // CGAL_HEADER_ONLY
 
+namespace {
+
 // standard error handlers
 // -----------------------
 CGAL_INLINE_FUNCTION
@@ -110,6 +114,8 @@ _standard_warning_handler( const char *,
 	 << std::endl;
 }
 
+} // anonymous namespace
+
 #ifdef CGAL_HEADER_ONLY
 
 inline Failure_function& get_static_error_handler()
@@ -124,6 +130,9 @@ inline Failure_function& get_static_warning_handler()
 }
 
 #else // CGAL_HEADER_ONLY
+
+namespace {
+
 // default handler settings
 // ------------------------
 Failure_function _error_handler   = _standard_error_handler;
@@ -134,10 +143,10 @@ inline Failure_function& get_static_error_handler()
 inline Failure_function& get_static_warning_handler()
 { return _warning_handler; }
 
-#endif // CGAL_HEADER_ONLY
-
 } // anonymous namespace
 
+#endif // CGAL_HEADER_ONLY
+
 // failure functions
 // -----------------
 CGAL_INLINE_FUNCTION
